@@ -38,13 +38,37 @@ class Tier(object):
         self._indexed = False
         self._reindex()
         self._indexed = True
+
+    def add_points(self, points):
+        """Adds points to the Tier."""
+        
+        for point in points:
+            point = Point(point.time, point.value, superior_PitchTier=self)
+            
+            if point.time < self.start_time or point.time > self.end_time:
+                raise Exception('Trying to set a point outside of time linits.')
+            
+            time = point.time
+            
+            for this_point in self.__points:
+                if this_point.time==time:
+                    raise Exception(f'Point object with time {time} already exists.')
+            
+            self.__points.append(point)
+        
+        self.__points_to_sort = [(point.time, point) for point in self.__points]
+        self.__points = [i[1] for i in sorted(self.__points_to_sort, key=lambda x: x[0])]
+        
+        self._indexed = False
+        self._reindex()
+        self._indexed = True
     
     def to_plot(self, start_time=None, end_time=None):
-        """Plots the points of the Tier from between two time points. If the time points are not specified, start time and end time are used. To change related parameters, use parameters.parameters."""
+        """Plots the points of the Tier from between two time points. If the time points are not specified, start time and end time are used. To change related parameters, use parameters."""
         import seaborn as sns
         from matplotlib import pyplot as plt
 
-        plt.figure(figsize=parameters['to_plot']['size'])
+        plt.figure(figsize=parameters['to_plot.size'])
         
         if start_time==None:
             start_time = self.start_time
@@ -60,7 +84,7 @@ class Tier(object):
         return plot
     
     def get_point(self, by_target, by):
-        """Get Point of the Tier with chosen method. To change related parameters, use parameters.parameters."""
+        """Get Point of the Tier with chosen method. To change related parameters, use parameters."""
         
         if by.by_method not in _by.by_methods:
             raise Exception(f'Invalid by_method. Use help() to see valid methods.')
@@ -83,11 +107,38 @@ class Tier(object):
                 if point==by_target:
                     return point
         
-        if not parameters['points']['ignore_missing_point']:
+        if not parameters['points.ignore_missing_point']:
             raise Exception('Point not found.')
+    
+    def get_points(self, by_target, by):
+
+        points = []
+        
+        if by.by_method not in _by.by_methods:
+            raise Exception(f'Invalid by_method. Use help() to see valid methods.')
+        
+        if by.by_method=='by_point':
+            for point in by_target:
+                if point in self.__points:
+                    points.append(point)
+                elif parameters['points.ignore_missing_point']:
+                    pass
+                else:
+                    raise Exception('Point not found.')
+
+        elif by.by_method=='by_index':
+            for index in range(by_target[0], by_target[1]+1):
+                points.append(self.get_point(index, _by.Index()))
+                
+        elif by.by_method=='by_time':
+            for point in self.__points:
+                if by_target[0] <= point.time <= by_target[1]:
+                    points.append(point)
+        
+        return points
         
     def remove_point(self, by_target, by):
-        """Remove Point of the Tier with chosen method. To change related parameters, use parameters.parameters."""
+        """Remove Point of the Tier with chosen method. To change related parameters, use parameters."""
         
         if by.by_method not in _by.by_methods:
             raise Exception(f'Invalid by_method. Use help() to see valid methods.')
@@ -102,9 +153,27 @@ class Tier(object):
         self._indexed = False
         self._reindex()
         self._indexed = True
-    
+
+    def remove_points(self, by_target, by):
+        """Remove Point of the Tier with chosen method. To change related parameters, use parameters."""
+        
+        if by.by_method not in _by.by_methods:
+            raise Exception(f'Invalid by_method. Use help() to see valid methods.')
+        
+        points = self.get_points(by_target, by)
+        
+        for point in points:
+            if point==None:
+                pass
+            else:
+                self.__points.remove(point)
+        
+        self._indexed = False
+        self._reindex()
+        self._indexed = True
+
     def shift_point_to_time(self, target_time, by_target, by):
-        """Shift Point of the Tier to chosen time with chosen method. To change related parameters, use parameters.parameters."""
+        """Shift Point of the Tier to chosen time with chosen method. To change related parameters, use parameters."""
 
         if by.by_method not in _by.by_methods:
             raise Exception(f'Invalid by_method. Use help() to see valid methods.')
@@ -123,29 +192,9 @@ class Tier(object):
             self.add_point(point)
     
     def batch_raise_value(self, by_target, by, value):
-        """Batch raise or lower value of points of the Tier. To change related parameters, use parameters.parameters."""
-        points = []
-        
-        if by.by_method not in _by.by_methods:
-            raise Exception(f'Invalid by_method. Use help() to see valid methods.')
-        
-        if by.by_method=='by_point':
-            for point in by_target:
-                if point in self.__points:
-                    points.append(point)
-                elif parameters['points']['ignore_missing_point']:
-                    pass
-                else:
-                    raise Exception('Point not found.')
+        """Batch raise or lower value of points of the Tier. To change related parameters, use parameters."""
 
-        elif by.by_method=='by_index':
-            for index in range(by_target[0], by_target[1]):
-                points.append(self.get_point(index, _by.Index()))
-                
-        elif by.by_method=='by_time':
-            for point in self.__points:
-                if by_target[0] <= point.time <= by_target[1]:
-                    points.append(point)
+        points = self.get_points(by_target, by)
         
         for point in points:
             point.value+=value
@@ -168,16 +217,16 @@ class Tier(object):
         return df
     
     def write_to_file(self, file=''):
-        """Write the Tier to file. By default saves to the original directory, if any. To change related parameters, use parameters.parameters."""
+        """Write the Tier to file. By default saves to the original directory, if any. To change related parameters, use parameters."""
         
         if file=='':
             file = f'{self.original_dir}/{self.name}.{self.tier_type}'
         
         if os.path.isfile(file):
-            if not parameters['write_to_file']['replace']:
-                if parameters['write_to_file']['duplicate']:
+            if not parameters['write_to_file.replace']:
+                if parameters['write_to_file.duplicate']:
                     original_dir = os.path.dirname(file)
-                    file_name = f"{os.path.basename(file).split('.')[0]} {parameters['write_to_file']['duplicated name extension']}"
+                    file_name = f"{os.path.basename(file).split('.')[0]} {parameters['write_to_file.duplicated_name_extension']}"
                     file_extension = os.path.basename(file).split('.')[1]
                     
                     file = f'{original_dir}/{file_name}.{file_extension}'
